@@ -9,7 +9,7 @@ setMethod(
   f = "jackknife",
   signature = c(object = "EventDate"),
   definition = function(object, level = 0.95,
-                        calendar = getOption("kairos.calendar"),
+                        calendar = get_calendar(),
                         progress = getOption("kairos.progress"),
                         verbose = getOption("kairos.verbose"), ...) {
     ## Get data
@@ -90,7 +90,7 @@ setMethod(
   f = "bootstrap",
   signature = c(object = "EventDate"),
   definition = function(object, level = 0.95, probs = c(0.05, 0.95), n = 1000,
-                        calendar = getOption("kairos.calendar"),
+                        calendar = get_calendar(),
                         progress = getOption("kairos.progress"), ...) {
     ## Get data
     fit_model <- object@model
